@@ -397,7 +397,8 @@ public class ResourcesListViewPanel extends FramedPanel {
 		createContextMenu();
 
 		VerticalLayoutContainer main = new VerticalLayoutContainer();
-		main.setScrollMode(ScrollMode.AUTO);
+		main.setAdjustForScroll(false);
+		main.setScrollMode(ScrollMode.NONE);
 		// main.setAdjustForScroll(true);
 		main.setBorders(true);
 		main.add(toolBar, new VerticalLayoutData(1, -1));
